==> Paws-0.02.tar.gz: Paws-0.02/lib/Paws/EMR/SetVisibleToAllUsers.pm <==

package Paws::EMR::SetVisibleToAllUsers {
  use Moose;
  has JobFlowIds => (is => 'ro', isa => 'ArrayRef[Str]', required => 1);
  has VisibleToAllUsers => (is => 'ro', isa => 'Bool', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'SetVisibleToAllUsers');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::EMR::SetVisibleToAllUsers - Arguments for method SetVisibleToAllUsers on Paws::EMR

=head1 DESCRIPTION

This class represents the parameters used for calling the method SetVisibleToAllUsers on the 
Amazon Elastic MapReduce service. Use the attributes of this class
as arguments to method SetVisibleToAllUsers.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to SetVisibleToAllUsers.

As an example:

  $service_obj->SetVisibleToAllUsers(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> JobFlowIds => ArrayRef[Str]

  

Identifiers of the job flows to receive the new visibility setting.










=head2 B<REQUIRED> VisibleToAllUsers => Bool

  

Whether the specified job flows are visible to all IAM users of the AWS
account associated with the job flow. If this value is set to True, all
IAM users of that AWS account can view and, if they have the proper IAM
policy permissions set, manage the job flows. If it is set to False,
only the IAM user that created a job flow can view and manage it.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for SetVisibleToAllUsers in Paws::EMR

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.08.tar.gz: Paws-0.08/lib/Paws/EMR/SetVisibleToAllUsers.pm <==

package Paws::EMR::SetVisibleToAllUsers {
  use Moose;
  has JobFlowIds => (is => 'ro', isa => 'ArrayRef[Str]', required => 1);
  has VisibleToAllUsers => (is => 'ro', isa => 'Bool', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'SetVisibleToAllUsers');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::EMR::SetVisibleToAllUsers - Arguments for method SetVisibleToAllUsers on Paws::EMR

=head1 DESCRIPTION

This class represents the parameters used for calling the method SetVisibleToAllUsers on the 
Amazon Elastic MapReduce service. Use the attributes of this class
as arguments to method SetVisibleToAllUsers.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to SetVisibleToAllUsers.

As an example:

  $service_obj->SetVisibleToAllUsers(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> JobFlowIds => ArrayRef[Str]

  

Identifiers of the job flows to receive the new visibility setting.










=head2 B<REQUIRED> VisibleToAllUsers => Bool

  

Whether the specified job flows are visible to all IAM users of the AWS
account associated with the job flow. If this value is set to True, all
IAM users of that AWS account can view and, if they have the proper IAM
policy permissions set, manage the job flows. If it is set to False,
only the IAM user that created a job flow can view and manage it.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method SetVisibleToAllUsers in L<Paws::EMR>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
